@@ -1,69 +1,57 @@
 import time
-from typing import NamedTuple
 
 import cloudscraper
 from bs4 import BeautifulSoup
 from bs4.element import Tag
 
+from subsearch.data.data_fields import (
+    DownloadData,
+    FormattedData,
+    ProviderUrlData,
+    ReleaseData,
+    UserData,
+)
 from subsearch.utils import log
 from subsearch.utils.exceptions import CaptchaError
-from subsearch.utils.raw_config import UserParameters
-from subsearch.utils.string_parser import FileSearchParameters
 
 SCRAPER = cloudscraper.create_scraper(browser={"browser": "chrome", "platform": "android", "desktop": False})
 
 
-class DownloadData(NamedTuple):
-    name: str
-    file_path: str
-    url: str
-    idx_num: int
-    idx_lenght: int
-
-
-class FormattedData(NamedTuple):
-    provider: str
-    release: str
-    url: str
-    pct_result: int
-    formatted_release: str
-    formatted_url: str
-
-
 class BaseProvider:
     """
     Base class for providers
     """
 
-    def __init__(self, parameters: FileSearchParameters, user_parameters: UserParameters):
+    def __init__(self, rd: ReleaseData, ud: UserData, pud: ProviderUrlData):
+        self.release_data = rd
+        self.user_data = ud
+        self.provider_data = pud
+
         # file parameters
-        self.parameters = parameters
-        self.user_parameters = user_parameters
-        self.url_subscene = parameters.url_subscene
-        self.url_opensubtitles = parameters.url_opensubtitles
-        self.url_opensubtitles_hash = parameters.url_opensubtitles_hash
-        self.url_yifysubtitles = parameters.url_yifysubtitles
-        self.title = parameters.title
-        self.year = parameters.year
-        self.season = parameters.season
-        self.season_ordinal = parameters.season_ordinal
-        self.episode = parameters.episode
-        self.episode_ordinal = parameters.episode_ordinal
-        self.series = parameters.series
-        self.release = parameters.release
-        self.group = parameters.group
-        self.file_hash = parameters.file_hash
-        self.definitive_match = parameters.definitive_match
+        self.title = rd.title
+        self.year = rd.year
+        self.season = rd.season
+        self.season_ordinal = rd.season_ordinal
+        self.episode = rd.episode
+        self.episode_ordinal = rd.episode_ordinal
+        self.series = rd.series
+        self.release = rd.release
+        self.group = rd.group
+        self.file_hash = rd.file_hash
         # user parameters
-        self.current_language = user_parameters.current_language
-        self.hi_sub = user_parameters.hearing_impaired
-        self.non_hi_sub = user_parameters.non_hearing_impaired
-        self.pct_threashold = user_parameters.percentage
-        self.show_download_window = user_parameters.show_download_window
+        self.current_language = ud.current_language
+        self.hi_sub = ud.hearing_impaired
+        self.non_hi_sub = ud.non_hearing_impaired
+        self.pct_threashold = ud.percentage
+        self.show_download_window = ud.show_download_window
+        # provider url data
+        self.url_subscene = pud.subscene
+        self.url_opensubtitles = pud.opensubtitles
+        self.url_opensubtitles_hash = pud.opensubtitles_hash
+        self.url_yifysubtitles = pud.yifysubtitles
 
     def is_movie(self, key: str) -> bool:
         if key.lower() == f"{self.title} ({self.year})":
-            log.output(f"Movie {key} found")
             return True
         return False
 
@@ -75,13 +63,11 @@ class BaseProvider:
         _year = int(self.year) - 1
         the_year_before = f"{self.title} ({_year})"
         if key.lower().startswith(the_year_before):
-            log.output(f"Movie {key} found")
             return True
         return False
 
     def is_series(self, key: str) -> bool:
         if self.title and self.season_ordinal in key.lower() and self.series:
-            log.output(f"TV-Series {key} found")
             return True
         return False
 
@@ -117,20 +103,22 @@ def get_lxml_doc(url: str, features: str = "lxml") -> BeautifulSoup:
     return doc
 
 
-def named_tuple_zip_data(provider: str, video_tmp_directory: str, to_be_downloaded: dict[str, str]) -> list[DownloadData]:
+def pack_download_data(_provider: str, video_tmp_directory: str, to_be_downloaded: dict[str, str]) -> list[DownloadData]:
     download_info = []
     tbd_lenght = len(to_be_downloaded)
     for zip_idx, (zip_name, zip_url) in enumerate(to_be_downloaded.items(), start=1):
-        zip_fp = f"{video_tmp_directory}\\{provider}_{zip_idx}.zip"
-        data = DownloadData(name=zip_name, file_path=zip_fp, url=zip_url, idx_num=zip_idx, idx_lenght=tbd_lenght)
+        zip_fp = f"{video_tmp_directory}\\{_provider}_{zip_idx}.zip"
+        data = DownloadData(
+            provider=_provider, name=zip_name, file_path=zip_fp, url=zip_url, idx_num=zip_idx, idx_lenght=tbd_lenght
+        )
         download_info.append(data)
     return download_info
 
 
 def format_key_value_pct(_provider: str, key: str, value: str, _pct_result: int) -> FormattedData:
-    lenght_str = sum(1 for char in f"[{_pct_result:>3}%  match]:")
+    lenght_str = sum(1 for char in f"{_pct_result:>3}% match:")
     number_of_spaces = " " * lenght_str
-    _match_release = f"[{_pct_result:>3}%  match]: {key}"
+    _match_release = f"{_pct_result:>3}% match: {key}"
     _url = f"{number_of_spaces} {value}"
     data = FormattedData(
         provider=_provider,
@@ -145,7 +133,8 @@ def format_key_value_pct(_provider: str, key: str, value: str, _pct_result: int)
 
 def log_and_sort_list(_provider: str, _list: list[FormattedData], pct: int) -> list[FormattedData]:
     _list.sort(key=lambda x: x.pct_result, reverse=True)
-    log.output(f"\n[Sorted List from {_provider}]", False)
+    log.output("")
+    log.output(f"--- [Sorted List from {_provider}] ---", False)
     hbd_printed = False
     hnbd_printed = False
     for data in _list:
